Changelog
---------

0.6.2 (2016-08-26)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to query a user by id.
  [href]

0.6.1 (2016-08-26)
~~~~~~~~~~~~~~~~~~~

- Log registrations for fail2ban integration.
  [href]

0.6.0 (2016-08-26)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to register new users and activate them with a token.
  [href]

0.5.0 (2016-08-24)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to create a login auth object to the current path.
  [href]

0.4.4 (2016-07-19)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with Morepath 0.15.
  [href]

0.4.3 (2016-06-28)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to activate/deactivate users.
  [href]

- Adds the ability to list users through the cli.
  [href]

0.4.2 (2016-05-30)
~~~~~~~~~~~~~~~~~~~

- Catches signature verifcation error responses to the yubico server.
  [href]

0.4.1 (2016-05-30)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with onegov.core 0.21.0.

0.4.0 (2016-01-13)
~~~~~~~~~~~~~~~~~~~

- Adds an initials property to the user.
  [href]

- Adds a title property to the user.
  [href]

0.3.1 (2015-12-16)
~~~~~~~~~~~~~~~~~~~

- Turns the Yubikey field into an ordinary string field.
  [href]

- Replayed Yubikeys no longer lead to an exception.
  [href]

0.3.0 (2015-11-20)
~~~~~~~~~~~~~~~~~~~

- Adds 2FA support with Yubikey as the first possible option.
  [href]

0.2.1 (2015-10-15)
~~~~~~~~~~~~~~~~~~~

- Use 'de_CH' translation instead of 'de'.
  [href]

0.2.0 (2015-10-12)
~~~~~~~~~~~~~~~~~~~

- Removes Python 2.x support.
  [href]

0.1.1 (2015-10-06)
~~~~~~~~~~~~~~~~~~~

- Fixes 'to' parameter not being passed on by Auth.from_request.
  [href]

0.1.0 (2015-10-05)
~~~~~~~~~~~~~~~~~~~

- Adds a generic authentication model for login/logout views.
  [href]

0.0.3 (2015-10-02)
~~~~~~~~~~~~~~~~~~~

- Adds a generic login form
  [href]

0.0.2 (2015-06-26)
~~~~~~~~~~~~~~~~~~~

- Adds support for onegov.core.upgrade
  [href]

- Remove support for Python 3.3
  [href]

0.0.1 (2015-04-29)
~~~~~~~~~~~~~~~~~~~

- Initial Release [href]
